@@ -17,7 +17,7 @@ def normalize_datetime(dt):
     if ms < 1000:
         return dt.replace(microsecond=0)
     elif ms > 999000:
-        return dt.replace(second=dt.second + 1, microsecond=0)
+        return dt.replace(microsecond=0) + datetime.timedelta(seconds=1)
 
     return dt
 
@@ -35,7 +35,7 @@ def xlsx2csv(f, output=None, **kwargs):
 
     writer = CSVKitWriter(output)
 
-    book = load_workbook(f, use_iterators=True)
+    book = load_workbook(f, use_iterators=True, data_only=True)
     if 'sheet' in kwargs:
         sheet = book.get_sheet_by_name(kwargs['sheet'])
     else:
