@@ -11,13 +11,15 @@ class CSVSort(CSVKitUtility):
 
     def add_arguments(self):        
         self.argparser.add_argument('-y', '--snifflimit', dest='snifflimit', type=int,
-                            help='Limit CSV dialect sniffing to the specified number of bytes.')
+                            help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing entirely.')
         self.argparser.add_argument('-n', '--names', dest='names_only', action='store_true',
                             help='Display column names and indices from the input CSV and exit.')
         self.argparser.add_argument('-c', '--columns', dest='columns',
                             help='A comma separated list of column indices or names to be extracted. Defaults to all columns.')
         self.argparser.add_argument('-r', '--reverse', dest='reverse', action='store_true',
-                help='Sort in descending order.')
+                            help='Sort in descending order.')
+        self.argparser.add_argument('--no-inference', dest='no_inference', action='store_true',
+                            help='Disable type inference when parsing the input.')
 
     def main(self):
         if self.args.names_only:
@@ -30,7 +32,15 @@ class CSVSort(CSVKitUtility):
         else:
             table_name = 'csvsql_table'
 
-        tab = table.Table.from_csv(self.args.file, name=table_name, snifflimit=self.args.snifflimit, **self.reader_kwargs)
+        tab = table.Table.from_csv(
+            self.args.file,
+            name=table_name,
+            snifflimit=self.args.snifflimit,
+            no_header_row=self.args.no_header_row,
+            infer_types=(not self.args.no_inference),
+            **self.reader_kwargs
+        )
+        
         column_ids = parse_column_identifiers(self.args.columns, tab.headers(), self.args.zero_based)
 
         rows = tab.to_rows(serialize_dates=True) 
